#

##

##

##

###

###

###

###

##

    	🏗️ The Architecture

    	Important

    		Don't use "volts" for these modules,

    			"shares",
    			"botanist"

    			"body_scan",
    			"botanical"

    	Principles

    			The idea is that building codependecies (or cyclic depedencies)
    			into the status assertation framework is a recipe for confusion.

    			As in, volts perhaps shouldn't include a module that
    			requires volts for status assertation.

    			Therefore the directed acyclic chart of status check frameworks is:

    				[ unit test, pytest ] -> "body_scan" -> volts

    	The Structure

    			🌐
    			story 4:

    				# "ships" is the latest iteration of "botanical" and "botanist"

    			🌐
    			story 3: "volts"

    				requires:
    					{status} "body_scan"

    					"botanical"
    						{status} "body_scan"

    					"shares"
    						{status} "body_scan"

    			🌐
    			story 2: "body_scan"

    				requires
    					{status} "unittest"

    					"botanist"
    						{status} "unittest"

    			🌐
    			story 1: "unittest"

    				# https://docs.python.org/3/library/unittest.html

    	journal

    			1:
    				This is module started as a replica of "body_scan",
    				where it uses "body_scan" as the status monitor.

    				In contrast, "body_scan" uses unittest as the status
    				monitor.